@@ -35,6 +35,13 @@ source $GRENADE_DIR/functions
 # only the first error that occurred.
 set -o errexit
 
+if grep -q '_store *= *mongodb' /etc/zaqar/zaqar.conf; then
+    # mongo-tools is the name of the package which includes mongodump on
+    # basically all distributions (Ubuntu, Debian, Fedora, CentOS and
+    # openSUSE).
+    install_package mongo-tools
+fi
+
 if grep -q 'management_store *= *mongodb' /etc/zaqar/zaqar.conf; then
     mongodump --db zaqar_mgmt --out $SAVE_DIR/zaqar-mongodb-mgmt-dump.$BASE_RELEASE
 fi
@@ -45,7 +52,7 @@ fi
 
 if grep -q 'message_store *= *redis' /etc/zaqar/zaqar.conf; then
     redis-cli save
-    cp /var/lib/redis/dump.rdb $SAVE_DIR/zaqar-redis-message-dump-$BASE_RELEASE.rdb
+    sudo cp /var/lib/redis/dump.rdb $SAVE_DIR/zaqar-redis-message-dump-$BASE_RELEASE.rdb
 fi
 
 # Upgrade Zaqar
@@ -65,8 +72,8 @@ source $ZAQAR_DEVSTACK_DIR/plugin.sh
 set -o xtrace
 
 function wait_for_keystone {
-    local auth_uri=http://${ZAQAR_SERVICE_HOST}/identity
-    if ! wait_for_service $SERVICE_TIMEOUT ${auth_uri}/v$IDENTITY_API_VERSION/; then
+    local www_authenticate_uri=http://${ZAQAR_SERVICE_HOST}/identity
+    if ! wait_for_service $SERVICE_TIMEOUT ${www_authenticate_uri}/v$IDENTITY_API_VERSION/; then
         die $LINENO "keystone did not start"
     fi
 }
@@ -100,7 +107,7 @@ fi
 
 if grep -q 'message_store *= *redis' /etc/zaqar/zaqar.conf; then
     redis-cli save
-    cp /var/lib/redis/dump.rdb $SAVE_DIR/zaqar-redis-message-dump-$TARGET_RELEASE.rdb
+    sudo cp /var/lib/redis/dump.rdb $SAVE_DIR/zaqar-redis-message-dump-$TARGET_RELEASE.rdb
 fi
 
 set +o xtrace
