@@ -11,8 +11,6 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations under
 # the License.
-
-from __future__ import print_function
 import functools
 import sys
 
@@ -34,7 +32,7 @@ def _fail(returncode, ex):
 
     print(ex, file=sys.stderr)
 
-    LOG.exception(ex)
+    LOG.exception('Exception encountered:')
     sys.exit(returncode)
 
 
