@@ -108,6 +108,16 @@ class ClaimDoesNotExist(DoesNotExist):
                                                 project=project)
 
 
+class ClaimDoesNotMatch(ExceptionBase):
+
+    msg_format = (u'Claim {cid} does not exist in the claim_ids parameter in'
+                  u'queue {queue} for project {project}')
+
+    def __init__(self, cid, queue, project):
+        super(ClaimDoesNotMatch, self).__init__(cid=cid, queue=queue,
+                                                project=project)
+
+
 class MessageIsClaimed(NotPermitted):
 
     msg_format = u'Message {mid} is claimed'
@@ -206,7 +216,28 @@ class PoolAlreadyExists(Conflict):
     msg_format = u'The database URI is in use by another pool.'
 
 
+class PoolRedisNotSupportGroup(ExceptionBase):
+
+    msg_format = (u'Redis not support pool_goup, please use flavor ')
+
+
 class SubscriptionAlreadyExists(Conflict):
 
     msg_format = (u'Such subscription already exists. Subscriptions '
                   u'are unique by project + queue + subscriber URI.')
+
+
+class TopicDoesNotExist(DoesNotExist):
+
+    msg_format = u'Topic {name} does not exist for project {project}'
+
+    def __init__(self, name, project):
+        super(TopicDoesNotExist, self).__init__(name=name, project=project)
+
+
+class TopicIsEmpty(ExceptionBase):
+
+    msg_format = u'Topic {name} in project {project} is empty'
+
+    def __init__(self, name, project):
+        super(TopicIsEmpty, self).__init__(name=name, project=project)
