@@ -21,7 +21,6 @@ import time
 from oslo_log import log as logging
 from oslo_utils import encodeutils
 import redis
-import six
 
 from zaqar.storage import errors
 
@@ -69,6 +68,7 @@ def scope_queue_name(queue=None, project=None):
     # TODO(prashanthr_) : Try to reuse this utility. Violates DRY
     return normalize_none_str(project) + '.' + normalize_none_str(queue)
 
+
 # NOTE(prashanthr_): Aliase the scope_queue_name function
 # to be used in the pools and claims controller as similar
 # functionality is required to scope redis id's.
@@ -152,8 +152,8 @@ def raises_conn_error(func):
     def wrapper(*args, **kwargs):
         try:
             return func(*args, **kwargs)
-        except redis.exceptions.ConnectionError as ex:
-            LOG.exception(ex)
+        except redis.exceptions.ConnectionError:
+            LOG.exception('Connection failure:')
             raise errors.ConnectionError()
 
     return wrapper
@@ -230,7 +230,7 @@ def msg_delayed_filter(message, now):
 def msg_echo_filter(message, client_uuid):
     """Return True IFF the specified client posted the message."""
 
-    return message.client_uuid == six.text_type(client_uuid)
+    return message.client_uuid == str(client_uuid)
 
 
 def msg_expired_filter(message, now):
