@@ -13,13 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import division
-
 import json
 import uuid
 
 import ddt
 
+from zaqar.common import consts
 from zaqar.tests.functional import base
 from zaqar.tests.functional import helpers
 
@@ -74,7 +73,7 @@ class TestMessages(base.V1_1FunctionalTestBase):
         doc = helpers.create_message_body_v1_1(messagecount=1)
 
         result = self.client.post(data=doc)
-        self.assertEqual(result.status_code, 201)
+        self.assertEqual(201, result.status_code)
 
         response_headers = set(result.headers.keys())
         self.assertIsSubset(self.headers_response_with_body, response_headers)
@@ -84,30 +83,30 @@ class TestMessages(base.V1_1FunctionalTestBase):
         url = self.cfg.zaqar.url + href
 
         result = self.client.get(url)
-        self.assertEqual(result.status_code, 200)
+        self.assertEqual(200, result.status_code)
 
         # Compare message metadata
         result_body = result.json()['body']
         posted_metadata = doc['messages'][0]['body']
-        self.assertEqual(result_body, posted_metadata)
+        self.assertEqual(posted_metadata, result_body)
 
         # Post a claim & verify the include_claimed flag.
         url = self.queue_url + '/claims'
         doc = {"ttl": 300, "grace": 100}
         result = self.client.post(url, data=doc)
-        self.assertEqual(result.status_code, 201)
+        self.assertEqual(201, result.status_code)
 
         params = {'include_claimed': True,
                   'echo': True}
         result = self.client.get(params=params)
-        self.assertEqual(result.status_code, 200)
+        self.assertEqual(200, result.status_code)
 
         response_message_body = result.json()["messages"][0]["body"]
-        self.assertEqual(response_message_body, posted_metadata)
+        self.assertEqual(posted_metadata, response_message_body)
 
         # By default, include_claimed = false
         result = self.client.get(self.message_url)
-        self.assertEqual(result.status_code, 200)
+        self.assertEqual(200, result.status_code)
 
     test_message_single_insert.tags = ['smoke', 'positive']
 
@@ -117,16 +116,16 @@ class TestMessages(base.V1_1FunctionalTestBase):
         doc = helpers.create_message_body_v1_1(messagecount=message_count)
 
         result = self.client.post(data=doc)
-        self.assertEqual(result.status_code, 201)
+        self.assertEqual(201, result.status_code)
 
         # GET on posted messages
         location = result.headers['location']
         url = self.cfg.zaqar.url + location
         result = self.client.get(url)
-        self.assertEqual(result.status_code, 200)
+        self.assertEqual(200, result.status_code)
 
         # Verify that the response json schema matches the expected schema
-        self.assertSchema(result.json(), 'message_get_many')
+        self.assertSchema(result.json(), consts.MESSAGE_GET_MANY)
 
         self.skipTest('Bug #1273335 - Get set of messages returns wrong hrefs '
                       '(happens randomly)')
@@ -138,7 +137,7 @@ class TestMessages(base.V1_1FunctionalTestBase):
         posted_metadata = [msg['body'] for msg in doc['messages']]
         posted_metadata.sort()
 
-        self.assertEqual(result_body, posted_metadata)
+        self.assertEqual(posted_metadata, result_body)
 
     test_message_bulk_insert.tags = ['smoke', 'positive']
 
@@ -148,18 +147,18 @@ class TestMessages(base.V1_1FunctionalTestBase):
                                                default_ttl=True)
 
         result = self.client.post(data=doc)
-        self.assertEqual(result.status_code, 201)
+        self.assertEqual(201, result.status_code)
 
         # GET on posted message
         href = result.json()['resources'][0]
         url = self.cfg.zaqar.url + href
 
         result = self.client.get(url)
-        self.assertEqual(result.status_code, 200)
+        self.assertEqual(200, result.status_code)
 
         # Compare message metadata
         default_ttl = result.json()['ttl']
-        self.assertEqual(default_ttl, self.resource_defaults.message_ttl)
+        self.assertEqual(self.resource_defaults.message_ttl, default_ttl)
 
     test_message_default_ttl.tags = ['smoke', 'positive']
 
@@ -178,7 +177,7 @@ class TestMessages(base.V1_1FunctionalTestBase):
             messagecount=self.limits.max_messages_per_page)
 
         result = self.client.post(data=doc)
-        self.assertEqual(result.status_code, 201)
+        self.assertEqual(201, result.status_code)
 
         url = ''
         params['echo'] = True
@@ -196,7 +195,7 @@ class TestMessages(base.V1_1FunctionalTestBase):
                 href = result.json()['links'][0]['href']
                 url = self.cfg.zaqar.url + href
 
-        self.assertEqual(result.status_code, 204)
+        self.assertEqual(204, result.status_code)
 
     test_get_message.tags = ['smoke', 'positive']
 
@@ -205,17 +204,17 @@ class TestMessages(base.V1_1FunctionalTestBase):
         # Test Setup
         doc = helpers.create_message_body_v1_1(messagecount=1)
         result = self.client.post(data=doc)
-        self.assertEqual(result.status_code, 201)
+        self.assertEqual(201, result.status_code)
 
         # Delete posted message
         href = result.json()['resources'][0]
         url = self.cfg.zaqar.url + href
 
         result = self.client.delete(url)
-        self.assertEqual(result.status_code, 204)
+        self.assertEqual(204, result.status_code)
 
         result = self.client.get(url)
-        self.assertEqual(result.status_code, 404)
+        self.assertEqual(404, result.status_code)
 
     test_message_delete.tags = ['smoke', 'positive']
 
@@ -224,17 +223,17 @@ class TestMessages(base.V1_1FunctionalTestBase):
         doc = helpers.create_message_body_v1_1(messagecount=10)
         result = self.client.post(data=doc)
 
-        self.assertEqual(result.status_code, 201)
+        self.assertEqual(201, result.status_code)
 
         # Delete posted messages
         location = result.headers['Location']
         url = self.cfg.zaqar.url + location
 
         result = self.client.delete(url)
-        self.assertEqual(result.status_code, 204)
+        self.assertEqual(204, result.status_code)
 
         result = self.client.get(url)
-        self.assertEqual(result.status_code, 404)
+        self.assertEqual(404, result.status_code)
 
     test_message_bulk_delete.tags = ['smoke', 'positive']
 
@@ -242,7 +241,7 @@ class TestMessages(base.V1_1FunctionalTestBase):
         """Delete non-existing Messages."""
         result = self.client.delete('/non-existing')
 
-        self.assertEqual(result.status_code, 204)
+        self.assertEqual(204, result.status_code)
 
     test_message_delete_nonexisting.tags = ['negative']
 
@@ -251,14 +250,14 @@ class TestMessages(base.V1_1FunctionalTestBase):
         doc = helpers.create_message_body_v1_1(messagecount=3)
         result = self.client.post(data=doc)
 
-        self.assertEqual(result.status_code, 201)
+        self.assertEqual(201, result.status_code)
 
         # Delete posted message
         location = result.headers['Location']
         url = self.cfg.zaqar.url + location
         url += ',nonexisting'
         result = self.client.delete(url)
-        self.assertEqual(result.status_code, 204)
+        self.assertEqual(204, result.status_code)
 
     test_message_partial_delete.tags = ['negative']
 
@@ -268,21 +267,21 @@ class TestMessages(base.V1_1FunctionalTestBase):
         doc = helpers.create_message_body_v1_1(messagecount=limit)
         result = self.client.post(data=doc)
 
-        self.assertEqual(result.status_code, 201)
+        self.assertEqual(201, result.status_code)
 
         # Pop messages
         url = self.message_url + '?pop=' + str(limit)
 
         result = self.client.delete(url)
-        self.assertEqual(result.status_code, 200)
+        self.assertEqual(200, result.status_code)
 
         params = {'echo': True}
 
         result = self.client.get(self.message_url, params=params)
-        self.assertEqual(result.status_code, 200)
+        self.assertEqual(200, result.status_code)
 
         messages = result.json()['messages']
-        self.assertEqual(messages, [])
+        self.assertEqual([], messages)
 
     test_messages_pop.tags = ['smoke', 'positive']
 
@@ -293,17 +292,17 @@ class TestMessages(base.V1_1FunctionalTestBase):
             messagecount=self.limits.max_messages_per_page)
         result = self.client.post(data=doc)
 
-        self.assertEqual(result.status_code, 201)
+        self.assertEqual(201, result.status_code)
 
         # Pop messages
         url = self.message_url + '?pop=' + str(limit)
 
         result = self.client.delete(url)
-        self.assertEqual(result.status_code, 400)
+        self.assertEqual(400, result.status_code)
 
         params = {'echo': True}
         result = self.client.get(self.message_url, params=params)
-        self.assertEqual(result.status_code, 200)
+        self.assertEqual(200, result.status_code)
 
         messages = result.json()['messages']
         self.assertNotEqual(messages, [])
@@ -316,19 +315,19 @@ class TestMessages(base.V1_1FunctionalTestBase):
             messagecount=1)
         result = self.client.post(data=doc)
 
-        self.assertEqual(result.status_code, 201)
+        self.assertEqual(201, result.status_code)
         location = result.headers['Location']
 
         # Pop messages
         url = self.cfg.zaqar.url + location + '&pop=1'
 
         result = self.client.delete(url)
-        self.assertEqual(result.status_code, 400)
+        self.assertEqual(400, result.status_code)
 
         params = {'echo': True}
 
         result = self.client.get(self.message_url, params=params)
-        self.assertEqual(result.status_code, 200)
+        self.assertEqual(200, result.status_code)
 
         messages = result.json()['messages']
         self.assertNotEqual(messages, [])
@@ -340,10 +339,10 @@ class TestMessages(base.V1_1FunctionalTestBase):
         url = self.message_url + '?pop=2'
 
         result = self.client.delete(url)
-        self.assertEqual(result.status_code, 200)
+        self.assertEqual(200, result.status_code)
 
         messages = result.json()['messages']
-        self.assertEqual(messages, [])
+        self.assertEqual([], messages)
 
     test_messages_pop_empty_queue.tags = ['smoke', 'positive']
 
@@ -353,19 +352,19 @@ class TestMessages(base.V1_1FunctionalTestBase):
             messagecount=self.limits.max_messages_per_page)
         result = self.client.post(data=doc)
 
-        self.assertEqual(result.status_code, 201)
+        self.assertEqual(201, result.status_code)
 
         # Pop Single Message
         url = self.message_url + '?pop=1'
 
         result = self.client.delete(url)
-        self.assertEqual(result.status_code, 200)
+        self.assertEqual(200, result.status_code)
 
         # Get messages from the queue & verify message count
         params = {'echo': True, 'limit': self.limits.max_messages_per_page}
 
         result = self.client.get(self.message_url, params=params)
-        self.assertEqual(result.status_code, 200)
+        self.assertEqual(200, result.status_code)
 
         expected_msg_count = self.limits.max_messages_per_page - 1
         actual_msg_count = len(result.json()['messages'])
@@ -378,14 +377,14 @@ class TestMessages(base.V1_1FunctionalTestBase):
         doc = helpers.create_message_body_v1_1(messagecount=3)
         result = self.client.post(data=doc)
 
-        self.assertEqual(result.status_code, 201)
+        self.assertEqual(201, result.status_code)
 
         # Get posted message and a nonexisting message
         location = result.headers['Location']
         url = self.cfg.zaqar.url + location
         url += ',nonexisting'
         result = self.client.get(url)
-        self.assertEqual(result.status_code, 200)
+        self.assertEqual(200, result.status_code)
 
     test_message_partial_get.tags = ['negative']
 
@@ -393,7 +392,7 @@ class TestMessages(base.V1_1FunctionalTestBase):
     def test_message_bulk_insert_large_bodies(self, offset):
         """Insert just under than max allowed messages."""
         result = self._post_large_bulk_insert(offset)
-        self.assertEqual(result.status_code, 201)
+        self.assertEqual(201, result.status_code)
 
     test_message_bulk_insert_large_bodies.tags = ['positive']
 
@@ -401,7 +400,7 @@ class TestMessages(base.V1_1FunctionalTestBase):
     def test_message_bulk_insert_large_bodies_(self, offset):
         """Insert just under than max allowed messages."""
         result = self._post_large_bulk_insert(offset)
-        self.assertEqual(result.status_code, 400)
+        self.assertEqual(400, result.status_code)
 
     test_message_bulk_insert_large_bodies_.tags = ['negative']
 
@@ -416,7 +415,7 @@ class TestMessages(base.V1_1FunctionalTestBase):
                          helpers.generate_random_string(half_size + 1))
 
         result = self.client.post(data=doc)
-        self.assertEqual(result.status_code, 400)
+        self.assertEqual(400, result.status_code)
 
     test_message_bulk_insert_oversized.tags = ['negative']
 
@@ -428,7 +427,7 @@ class TestMessages(base.V1_1FunctionalTestBase):
         """
         params = {'limit': limit}
         result = self.client.get(params=params)
-        self.assertEqual(result.status_code, 400)
+        self.assertEqual(400, result.status_code)
 
     test_message_get_invalid_limit.tags = ['negative']
 
@@ -443,7 +442,7 @@ class TestMessages(base.V1_1FunctionalTestBase):
                           range(self.limits.max_messages_per_page + 1)))
         result = self.client.delete(url)
 
-        self.assertEqual(result.status_code, 400)
+        self.assertEqual(400, result.status_code)
 
     test_message_bulk_delete_negative.tags = ['negative']
 
@@ -460,7 +459,7 @@ class TestMessages(base.V1_1FunctionalTestBase):
 
         result = self.client.get(url)
 
-        self.assertEqual(result.status_code, 400)
+        self.assertEqual(400, result.status_code)
 
     test_message_bulk_get_negative.tags = ['negative']
 
@@ -469,7 +468,7 @@ class TestMessages(base.V1_1FunctionalTestBase):
         url = self.message_url + '?marker=invalid'
 
         result = self.client.get(url, headers=self.headers)
-        self.assertEqual(result.status_code, 200)
+        self.assertEqual(200, result.status_code)
         self.assertSchema(result.json(), 'message_list')
 
     test_get_messages_malformed_marker.tags = ['negative']
@@ -485,7 +484,7 @@ class TestMessages(base.V1_1FunctionalTestBase):
         header['Client-ID'] = client_id
 
         result = self.client.get(url, headers=header)
-        self.assertEqual(result.status_code, 400)
+        self.assertEqual(400, result.status_code)
 
     test_get_messages_invalid_client_id.tags = ['negative']
 
@@ -493,7 +492,7 @@ class TestMessages(base.V1_1FunctionalTestBase):
         """Get Non Existing Message."""
         path = '/non-existing-message'
         result = self.client.get(path)
-        self.assertEqual(result.status_code, 404)
+        self.assertEqual(404, result.status_code)
 
     test_query_non_existing_message.tags = ['negative']
 
@@ -501,7 +500,7 @@ class TestMessages(base.V1_1FunctionalTestBase):
         """Get Set of Non Existing Messages."""
         path = '?ids=not_there1,not_there2'
         result = self.client.get(path)
-        self.assertEqual(result.status_code, 404)
+        self.assertEqual(404, result.status_code)
 
     test_query_non_existing_message_set.tags = ['negative']
 
@@ -509,7 +508,7 @@ class TestMessages(base.V1_1FunctionalTestBase):
         """Delete Non Existing Message."""
         path = '/non-existing-message'
         result = self.client.delete(path)
-        self.assertEqual(result.status_code, 204)
+        self.assertEqual(204, result.status_code)
 
     test_delete_non_existing_message.tags = ['negative']
 
@@ -524,4 +523,4 @@ class TestMessages(base.V1_1FunctionalTestBase):
         doc = helpers.create_message_body_v1_1(messagecount=1)
 
         result = self.client.post(data=doc)
-        self.assertEqual(result.status_code, 400)
+        self.assertEqual(400, result.status_code)
