@@ -13,9 +13,9 @@
 # the License.
 
 import json
+from unittest import mock
 
 import ddt
-import mock
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
 
@@ -46,8 +46,8 @@ class ClaimsBaseTest(base.V1_1Base):
 
         with mock.patch.object(self.protocol, 'sendMessage') as msg_mock:
             self.protocol.onMessage(req, False)
-            resp = json.loads(msg_mock.call_args[0][0])
-            self.assertEqual(201, resp['headers']['status'])
+            resp = json.loads(msg_mock.call_args[0][0].decode())
+            self.assertIn(resp['headers']['status'], [201, 204])
 
         action = consts.MESSAGE_POST
         body = {"queue_name": "skittle",
@@ -70,7 +70,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(201, resp['headers']['status'])
 
     def tearDown(self):
@@ -84,7 +84,7 @@ class ClaimsBaseTest(base.V1_1Base):
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
 
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(204, resp['headers']['status'])
 
     @ddt.data('[', '[]', '.', '"fail"')
@@ -97,7 +97,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
 
         action = consts.CLAIM_UPDATE
@@ -105,7 +105,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
 
     def test_exceeded_claim(self):
@@ -120,7 +120,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
 
     @ddt.data((-1, -1), (59, 60), (60, 59), (60, 43201), (43201, 60))
@@ -136,7 +136,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
 
     @ddt.data(-1, 59, 43201)
@@ -153,7 +153,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
 
     def test_default_ttl_and_grace(self):
@@ -165,7 +165,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(201, resp['headers']['status'])
 
         action = consts.CLAIM_GET
@@ -174,7 +174,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
 
         self.assertEqual(200, resp['headers']['status'])
         self.assertEqual(self.defaults.claim_ttl, resp['body']['ttl'])
@@ -191,7 +191,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(201, resp['headers']['status'])
         claimed_messages = resp['body']['messages']
         claim_id = resp['body']['claim_id']
@@ -203,7 +203,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(204, resp['headers']['status'])
 
         # Listing messages, by default, won't include claimed, will echo
@@ -213,7 +213,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(200, resp['headers']['status'])
         self.assertEqual([], resp['body']['messages'])
 
@@ -224,7 +224,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(200, resp['headers']['status'])
         self.assertEqual([], resp['body']['messages'])
 
@@ -236,7 +236,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(200, resp['headers']['status'])
         self.assertEqual(resp['body']['messages'], [])
 
@@ -253,7 +253,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(200, resp['headers']['status'])
 
         # Include claimed messages this time, and echo
@@ -264,7 +264,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(200, resp['headers']['status'])
         self.assertEqual(len(claimed_messages), len(resp['body']['messages']))
 
@@ -278,7 +278,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(403,  resp['headers']['status'])
 
         # Delete the message and its associated claim
@@ -288,7 +288,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(204, resp['headers']['status'])
 
         # Try to get it from the wrong project
@@ -302,7 +302,7 @@ class ClaimsBaseTest(base.V1_1Base):
                 "message_id": message_id_2}
         req = test_utils.create_request(action, body, headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(404,  resp['headers']['status'])
 
         # Get the message
@@ -311,7 +311,7 @@ class ClaimsBaseTest(base.V1_1Base):
                 "message_id": message_id_2}
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(200, resp['headers']['status'])
 
         # Update the claim
@@ -323,7 +323,7 @@ class ClaimsBaseTest(base.V1_1Base):
                 "claim_id": claim_id}
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(204, resp['headers']['status'])
 
         # Get the claimed messages (again)
@@ -333,7 +333,7 @@ class ClaimsBaseTest(base.V1_1Base):
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
         query = timeutils.utcnow()
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(200, resp['headers']['status'])
         self.assertEqual(60, resp['body']['ttl'])
 
@@ -352,7 +352,7 @@ class ClaimsBaseTest(base.V1_1Base):
                 "claim_id": claim_id}
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(204, resp['headers']['status'])
 
         # Try to delete a message with an invalid claim ID
@@ -363,7 +363,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(400, resp['headers']['status'])
 
         # Make sure it wasn't deleted!
@@ -372,7 +372,7 @@ class ClaimsBaseTest(base.V1_1Base):
                 "message_id": message_id_2}
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(200, resp['headers']['status'])
 
         # Try to get a claim that doesn't exist
@@ -381,7 +381,7 @@ class ClaimsBaseTest(base.V1_1Base):
                 "claim_id": claim_id}
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(404,  resp['headers']['status'])
 
         # Try to update a claim that doesn't exist
@@ -392,7 +392,7 @@ class ClaimsBaseTest(base.V1_1Base):
                 "claim_id": claim_id}
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(404,  resp['headers']['status'])
 
     def test_post_claim_nonexistent_queue(self):
@@ -406,7 +406,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(204, resp['headers']['status'])
 
     def test_get_claim_nonexistent_queue(self):
@@ -419,7 +419,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(404,  resp['headers']['status'])
 
     def _get_a_claim(self):
@@ -433,7 +433,7 @@ class ClaimsBaseTest(base.V1_1Base):
 
         req = test_utils.create_request(action, body, self.headers)
         self.protocol.onMessage(req, False)
-        resp = json.loads(send_mock.call_args[0][0])
+        resp = json.loads(send_mock.call_args[0][0].decode())
         self.assertEqual(201, resp['headers']['status'])
 
         return resp
