@@ -29,7 +29,7 @@ from zaqar.tests.unit.transport.wsgi import base
 
 
 @ddt.ddt
-class TestClaimsMongoDB(base.V2Base):
+class TestClaimsMongoDB(base.V1_1Base):
 
     config_file = 'wsgi_mongodb.conf'
 
@@ -66,7 +66,6 @@ class TestClaimsMongoDB(base.V2Base):
 
         for db in storage.message_databases:
             connection.drop_database(db)
-
         self.simulate_delete(self.queue_path, headers=self.headers)
 
         super(TestClaimsMongoDB, self).tearDown()
@@ -288,7 +287,7 @@ class TestClaimsMongoDB(base.V2Base):
         self.assertEqual(falcon.HTTP_404, self.srmock.status)
 
 
-class TestClaimsFaultyDriver(base.V2BaseFaulty):
+class TestClaimsFaultyDriver(base.V1_1BaseFaulty):
 
     config_file = 'wsgi_faulty.conf'
 
