@@ -34,8 +34,8 @@ try:
     import mimetools
     Message = mimetools.Message
 except ImportError:
-    from email.mime import message
-    Message = message.MIMEMessage
+    import email
+    Message = email.message_from_binary_file
 
 from zaqar.common import consts
 
@@ -80,8 +80,10 @@ class MessagingProtocol(websocket.WebSocketServerProtocol):
         # Deserialize the request
         try:
             if isBinary:
-                payload = msgpack.unpackb(payload, encoding='utf-8')
+                payload = msgpack.unpackb(payload)
             else:
+                if isinstance(payload, bytes):
+                    payload = payload.decode()
                 payload = json.loads(payload)
         except Exception:
             if isBinary:
@@ -207,7 +209,7 @@ class MessagingProtocol(websocket.WebSocketServerProtocol):
             self.sendMessage(msgpack.packb(resp.get_response()), True)
         else:
             pack_name = 'txt'
-            self.sendMessage(json.dumps(resp.get_response()), False)
+            self.sendMessage(json.dumps(resp.get_response()).encode(), False)
         if LOG.isEnabledFor(logging.INFO):
             api = resp._request._api
             status = resp._headers['status']
@@ -246,13 +248,16 @@ class NotificationProtocol(asyncio.Protocol):
                 self.write_status(b'405 Not Allowed')
                 return
             self._state = 'HEADERS'
-            self._subscriber_id = uri[1:]
+            self._subscriber_id = uri[1:].decode('utf-8')
 
         if self._state == 'HEADERS' and b'\r\n\r\n' in self._data:
             headers, self._data = self._data.split(b'\r\n\r\n', 1)
             headers = Message(io.BytesIO(headers))
-            length = headers.get(b'content-length')
+            # try both cases of content-length for backwards compatibility
+            length = headers.get(b'content-length',
+                                 headers.get('Content-Length'))
             if not length:
+                LOG.debug('Content-Length not provided in the data message')
                 self.write_status(b'400 Bad Request')
                 return
             self._length = int(length)
