@@ -1,5 +1,4 @@
-# Copyright (c) 2014 Rackspace, Inc.
-# Copyright 2014 Catalyst IT Ltd.
+# Copyright (c) 2013 Rackspace, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not
 # use this file except in compliance with the License.  You may obtain a copy
@@ -13,15 +12,7 @@
 # License for the specific language governing permissions and limitations under
 # the License.
 
-from oslo_log import log as logging
-
-from zaqar.common import decorators
-from zaqar.i18n import _
-from zaqar.transport import acl
-from zaqar.transport import utils
-from zaqar.transport.wsgi import errors as wsgi_errors
-
-LOG = logging.getLogger(__name__)
+import falcon
 
 
 class Resource(object):
@@ -31,13 +22,9 @@ class Resource(object):
     def __init__(self, driver):
         self._driver = driver
 
-    @decorators.TransportLog("Health item")
-    @acl.enforce("health:get")
     def on_get(self, req, resp, **kwargs):
-        try:
-            resp_dict = self._driver.health()
-            resp.body = utils.to_json(resp_dict)
-        except Exception:
-            description = _(u'Health status could not be read.')
-            LOG.exception(description)
-            raise wsgi_errors.HTTPServiceUnavailable(description)
+        resp.status = (falcon.HTTP_204 if self._driver.is_alive()
+                       else falcon.HTTP_503)
+
+    def on_head(self, req, resp, **kwargs):
+        resp.status = falcon.HTTP_204
