@@ -14,7 +14,6 @@
 # limitations under the License.
 
 from oslo_log import log as logging
-import six
 
 from zaqar.i18n import _
 from zaqar.storage import errors as storage_errors
@@ -50,11 +49,11 @@ class Resource(object):
                 oldest['href'] = base_path + oldest['id']
                 del oldest['id']
 
-            resp.content_location = req.path
             resp.body = utils.to_json(resp_dict)
             # status defaults to 200
 
-        except storage_errors.QueueIsEmpty:
+        except (storage_errors.QueueDoesNotExist,
+                storage_errors.QueueIsEmpty):
             resp_dict = {
                 'messages': {
                     'claimed': 0,
@@ -63,9 +62,10 @@ class Resource(object):
                 }
             }
             resp.body = utils.to_json(resp_dict)
+
         except storage_errors.DoesNotExist as ex:
             LOG.debug(ex)
-            raise wsgi_errors.HTTPNotFound(six.text_type(ex))
+            raise wsgi_errors.HTTPNotFound(str(ex))
 
         except Exception:
             description = _(u'Queue stats could not be read.')
